@@ -483,6 +483,7 @@ void Settings::saveSettings() {
 		settings.setValue("TimeLimitRatio", compilerList[i]->getTimeLimitRatio());
 		settings.setValue("MemoryLimitRatio", compilerList[i]->getMemoryLimitRatio());
 		settings.setValue("DisableMemoryLimitCheck", compilerList[i]->getDisableMemoryLimitCheck());
+		settings.setValue("InterpreterAsWatcher", compilerList[i]->getInterpreterAsWatcher());
 		QStringList configurationNames = compilerList[i]->getConfigurationNames();
 		QStringList compilerArguments = compilerList[i]->getCompilerArguments();
 		QStringList interpreterArguments = compilerList[i]->getInterpreterArguments();
@@ -534,10 +535,8 @@ void Settings::loadSettings() {
 	defaultInputFileExtension = settings.value("DefaultInputFileExtension", "in").toString();
 	defaultOutputFileExtension = settings.value("DefaultOuputFileExtension", "out").toString();
 	inputFileExtensions = settings.value("InputFileExtensions", QStringList() << "in").toStringList();
-	outputFileExtensions = settings
-	                           .value("OutputFileExtensions", QStringList() << "out"
-	                                                                        << "ans")
-	                           .toStringList();
+	outputFileExtensions =
+	    settings.value("OutputFileExtensions", QStringList() << "out" << "ans").toStringList();
 	settings.endGroup();
 	settings.beginGroup("VisualSettings");
 
@@ -609,6 +608,7 @@ void Settings::loadSettings() {
 		compiler->setTimeLimitRatio(settings.value("TimeLimitRatio").toDouble());
 		compiler->setMemoryLimitRatio(settings.value("MemoryLimitRatio").toDouble());
 		compiler->setDisableMemoryLimitCheck(settings.value("DisableMemoryLimitCheck").toBool());
+		compiler->setInterpreterAsWatcher(settings.value("InterpreterAsWatcher").toBool());
 		int configurationCount = settings.beginReadArray("Configuration");
 
 		for (int j = 0; j < configurationCount; j++) {
