@@ -8,6 +8,7 @@
  */
 
 #include "judgingthread.h"
+#include "LemonType.hpp"
 #include "base/LemonLog.hpp"
 #include "base/settings.h"
 #include "core/judgesharedvariables.h"
@@ -18,6 +19,7 @@
 #include <QDir>
 #include <QFile>
 #include <QFileInfo>
+#include <QRegularExpression>
 #include <QTextStream>
 #include <QTime>
 #include <QUuid>
@@ -86,8 +88,14 @@ void JudgingThread::setFullScore(int score) { fullScore = score; }
 
 void JudgingThread::setTimeLimit(int limit) { timeLimit = limit; }
 
+void JudgingThread::setRawTimeLimit(int limit) { rawTimeLimit = limit; }
+
 void JudgingThread::setMemoryLimit(int limit) { memoryLimit = limit; }
 
+void JudgingThread::setRawMemoryLimit(int limit) { rawMemoryLimit = limit; }
+
+void JudgingThread::setInterpreterAsWatcher(bool use) { interpreterAsWatcher = use; }
+
 auto JudgingThread::getTimeUsed() const -> int { return timeUsed; }
 
 auto JudgingThread::getMemoryUsed() const -> int { return memoryUsed; }
@@ -442,7 +450,7 @@ void JudgingThread::compareRealNumbers(const QString &contestantOutput) {
 	fclose(standardOutputFile);
 }
 
-void JudgingThread::specialJudge(const QString &fileName) {
+void JudgingThread::lemonSpecialJudge(const QString &fileName) {
 	if (! QFileInfo::exists(inputFile)) {
 		score = 0;
 		result = FileError;
@@ -557,6 +565,128 @@ void JudgingThread::specialJudge(const QString &fileName) {
 		result = CorrectAnswer;
 }
 
+void JudgingThread::testlibSpecialJudge(const QString &fileName) {
+	if (! QFileInfo::exists(inputFile)) {
+		score = 0;
+		result = FileError;
+		message = tr("Cannot find standard input file");
+		return;
+	}
+
+	if (! QFileInfo::exists(fileName)) {
+		score = 0;
+		result = FileError;
+		message = tr(R"(Cannot find contestant's output file)");
+		return;
+	}
+
+	if (! QFileInfo::exists(outputFile)) {
+		score = 0;
+		result = FileError;
+		message = tr("Cannot find standard output file");
+		return;
+	}
+
+	auto judge = std::make_unique<QProcess>(this);
+	QStringList arguments;
+	arguments << inputFile << fileName << outputFile;
+	judge->setStandardErrorFile(workingDirectory + "_score");
+	judge->start(Settings::dataPath() + task->getSpecialJudge(), arguments);
+
+	if (! judge->waitForStarted(-1)) {
+		score = 0;
+		result = InvalidSpecialJudge;
+		return;
+	}
+
+	QFile scoreFile(workingDirectory + "_score");
+
+	auto removeTempFiles = qScopeGuard([&] { scoreFile.remove(); });
+
+	QElapsedTimer timer;
+	timer.start();
+	bool flag = false;
+
+	while (timer.elapsed() < specialJudgeTimeLimit) {
+		if (judge->state() != QProcess::Running) {
+			flag = true;
+			break;
+		}
+
+		QCoreApplication::processEvents();
+
+		if (stopJudging) {
+			judge->kill();
+			return;
+		}
+
+		msleep(10);
+	}
+
+	if (! flag) {
+		judge->kill();
+		score = 0;
+		result = SpecialJudgeTimeLimitExceeded;
+		return;
+	}
+
+	if (! scoreFile.open(QFile::ReadOnly)) {
+		score = 0;
+		result = InvalidSpecialJudge;
+		return;
+	}
+
+	QTextStream scoreStream(&scoreFile);
+	message = scoreStream.readAll();
+
+	score = 0;
+
+	if (message.startsWith("ok")) {
+		score = fullScore;
+	}
+
+	if (message.startsWith("FAIL")) {
+		score = 0;
+		result = InvalidSpecialJudge;
+		return;
+	}
+
+	QRegularExpressionMatch m = QRegularExpression(R"(^partially correct \((\d+)\))").match(message);
+	if (m.hasMatch()) {
+		int val = m.captured(1).toInt();
+		score = val * fullScore / 100;
+	}
+
+	m = QRegularExpression(R"(^points ([0-9]*\.[0-9]+|[0-9]+))").match(message);
+	if (m.hasMatch()) {
+		double val = m.captured(1).toDouble();
+		score = val * fullScore;
+	}
+
+	if (scoreStream.status() == QTextStream::ReadCorruptData) {
+		score = 0;
+		result = InvalidSpecialJudge;
+		return;
+	}
+
+	scoreFile.close();
+
+	if (score < 0) {
+		score = 0;
+		result = InvalidSpecialJudge;
+		return;
+	}
+
+	if (score == 0)
+		result = WrongAnswer;
+
+	if (0 < score && score < fullScore)
+		result = PartlyCorrect;
+
+	if (score >= fullScore)
+		result = CorrectAnswer;
+}
+
 #ifdef Q_OS_WIN
 
 QString getRandomString(int length) {
@@ -888,31 +1018,25 @@ void JudgingThread::runProgram() {
 #ifdef Q_OS_LINUX
 	// TODO: rewrite with cgroup
 	QFile watcher(workingDirectory + QUuid::createUuid().toString(QUuid::Id128));
-	QFile::copy(":/watcher/watcher_unix", watcher.fileName());
+
+	if (interpreterAsWatcher) {
+		QFile::copy(executableFile, watcher.fileName());
+	} else {
+		QFile::copy(":/watcher/watcher_unix", watcher.fileName());
+	}
+
 	watcher.setPermissions(QFileDevice::ReadOwner | QFileDevice::WriteOwner | QFileDevice::ExeOwner);
 	auto *runner = new QProcess(this);
 	QStringList argumentsList;
 
-	argumentsList << "--ro-bind"
-	              << "/usr"
-	              << "/usr";
-	argumentsList << "--symlink"
-	              << "/usr/lib"
-	              << "/lib";
-	argumentsList << "--symlink"
-	              << "/usr/lib64"
-	              << "/lib64";
-	argumentsList << "--symlink"
-	              << "/usr/bin"
-	              << "/bin";
-	argumentsList << "--symlink"
-	              << "/usr/sbin"
-	              << "/sbin";
-	argumentsList << "--tmpfs"
-	              << "/tmp";
+	argumentsList << "--ro-bind" << "/usr" << "/usr";
+	argumentsList << "--symlink" << "/usr/lib" << "/lib";
+	argumentsList << "--symlink" << "/usr/lib64" << "/lib64";
+	argumentsList << "--symlink" << "/usr/bin" << "/bin";
+	argumentsList << "--symlink" << "/usr/sbin" << "/sbin";
+	argumentsList << "--tmpfs" << "/tmp";
 
-	argumentsList << "--unshare-all"
-	              << "--die-with-parent";
+	argumentsList << "--unshare-all" << "--die-with-parent";
 
 	argumentsList << "--chdir" << workingDirectory;
 
@@ -925,7 +1049,8 @@ void JudgingThread::runProgram() {
 
 	argumentsList << watcher.fileName();
 
-	argumentsList << QString("\"%1\" %2").arg(executableFile, arguments);
+	argumentsList << executableFile;
+	argumentsList << arguments;
 
 	if (task->getStandardInputCheck()) {
 		argumentsList << QFileInfo(inputFile).absoluteFilePath();
@@ -940,8 +1065,22 @@ void JudgingThread::runProgram() {
 	}
 
 	argumentsList << "_tmperr";
-	argumentsList << QString("%1").arg(timeLimit + extraTime);
+	argumentsList << QString("%1").arg(timeLimit);
 	argumentsList << QString("%1").arg(memoryLimit);
+	argumentsList << QString("%1").arg(rawTimeLimit);
+	argumentsList << QString("%1").arg(rawMemoryLimit);
+
+	if (task->getStandardInputCheck()) {
+		argumentsList << "";
+	} else {
+		argumentsList << task->getInputFileName();
+	}
+
+	if (task->getStandardOutputCheck()) {
+		argumentsList << "";
+	} else {
+		argumentsList << task->getOutputFileName();
+	}
 
 	qDebug() << argumentsList;
 
@@ -952,11 +1091,19 @@ void JudgingThread::runProgram() {
 #else
 
 	QFile watcher(workingDirectory + QUuid::createUuid().toString(QUuid::Id128));
-	QFile::copy(":/watcher/watcher_unix", watcher.fileName());
+
+	if (interpreterAsWatcher) {
+		QFile::copy(executableFile, watcher.fileName());
+	} else {
+		QFile::copy(":/watcher/watcher_unix", watcher.fileName());
+	}
+
 	watcher.setPermissions(QFileDevice::ReadOwner | QFileDevice::WriteOwner | QFileDevice::ExeOwner);
 	auto *runner = new QProcess(this);
 	QStringList argumentsList;
-	argumentsList << QString("\"%1\" %2").arg(executableFile, arguments);
+
+	argumentsList << executableFile;
+	argumentsList << arguments;
 
 	if (task->getStandardInputCheck()) {
 		argumentsList << QFileInfo(inputFile).absoluteFilePath();
@@ -971,8 +1118,24 @@ void JudgingThread::runProgram() {
 	}
 
 	argumentsList << "_tmperr";
-	argumentsList << QString("%1").arg(timeLimit + extraTime);
+	argumentsList << QString("%1").arg(timeLimit);
 	argumentsList << QString("%1").arg(memoryLimit);
+	argumentsList << QString("%1").arg(rawTimeLimit);
+	argumentsList << QString("%1").arg(rawMemoryLimit);
+
+	if (task->getStandardInputCheck()) {
+		argumentsList << "";
+	} else {
+		argumentsList << task->getInputFileName();
+	}
+
+	if (task->getStandardOutputCheck()) {
+		argumentsList << "";
+	} else {
+		argumentsList << task->getOutputFileName();
+	}
+
+	qDebug() << argumentsList;
 
 	runner->setProcessEnvironment(environment);
 	runner->setWorkingDirectory(workingDirectory);
@@ -984,6 +1147,7 @@ void JudgingThread::runProgram() {
 		delete runner;
 		score = 0;
 		result = CannotStartProgram;
+		message = "Start runner failed";
 		return;
 	}
 
@@ -991,7 +1155,10 @@ void JudgingThread::runProgram() {
 	QElapsedTimer timer;
 	timer.start();
 
-	while (timer.elapsed() <= timeLimit + extraTime) {
+	// Using rlimit to limit CPU time can only be accurate to seconds,
+	// so here it is rounded up to an integer second.
+	long long killTimeLimit = (timeLimit + 999) / 1000 * 1000 + extraTime;
+	while (timer.elapsed() <= killTimeLimit) {
 		if (runner->state() != QProcess::Running) {
 			isProgramFinishedInExtraTimeLimit = true;
 			break;
@@ -1021,65 +1188,61 @@ void JudgingThread::runProgram() {
 		runner->waitForFinished(-1);
 		delete runner;
 		score = 0;
-		result = TimeLimitExceeded;
 		timeUsed = memoryUsed = -1;
+		// Watcher usually needs to handle the situation of program timeout and kill it. Therefore, it is
+		// abnormal for watcher to timeout itself, and report FAIL instead of TLE.
+		result = CannotStartProgram;
+		message = "Watcher time limit exceeded";
 		return;
 	}
 
+	{
+		QString out = QString::fromLocal8Bit(runner->readAllStandardOutput().constData());
+		QTextStream stream(&out, QIODevice::ReadOnly);
+		stream >> timeUsed >> memoryUsed;
+	}
+
+	message = QString::fromLocal8Bit(runner->readAllStandardError().constData());
+
+	enum : int {
+		RS_AC = 0,
+		RS_FAIL = 1,
+		RS_RE = 2,
+		RS_TLE = 3,
+		RS_MLE = 4,
+	};
+
 	int code = runner->exitCode();
 
-	if (code == 1) {
-		delete runner;
-		score = 0;
-		result = CannotStartProgram;
-		timeUsed = memoryUsed = -1;
-		return;
-	}
-
-	if (code == 2) {
-		delete runner;
-		score = 0;
-		result = RunTimeError;
-		QFile file(workingDirectory + "_tmperr");
-
-		if (file.open(QFile::ReadOnly)) {
-			QTextStream stream(&file);
-			message = stream.readAll();
-			file.close();
-		}
-
-		timeUsed = memoryUsed = -1;
-		return;
-	}
-
-	QString out = QString::fromLocal8Bit(runner->readAllStandardOutput().constData());
-	QTextStream stream(&out, QIODevice::ReadOnly);
-	stream >> timeUsed >> memoryUsed;
-
-	if (memoryUsed <= 0)
-		memoryLimit = -1;
-
-	if (code == 3) {
-		delete runner;
-		score = 0;
-		result = TimeLimitExceeded;
-		timeUsed = -1;
-		return;
-	}
-
-	if (code == 4) {
-		delete runner;
-		score = 0;
-		result = MemoryLimitExceeded;
-		memoryUsed = -1;
-		return;
-	}
-
-	if (memoryUsed > memoryLimit * 1024LL * 1024) {
-		delete runner;
-		score = 0;
-		result = MemoryLimitExceeded;
-		return;
+	switch (code) {
+		case RS_RE:
+			result = RunTimeError;
+			score = 0;
+			[[fallthrough]];
+		case RS_AC: {
+			QFile file(workingDirectory + "_tmperr");
+			if (file.open(QFile::ReadOnly)) {
+				message += file.readAll().right(1024);
+				file.close();
+			}
+		} break;
+		case RS_FAIL:
+			result = CannotStartProgram;
+			score = 0;
+			break;
+		case RS_TLE:
+			result = TimeLimitExceeded;
+			score = 0;
+			break;
+		case RS_MLE:
+			result = MemoryLimitExceeded;
+			score = 0;
+			break;
+		default:
+			result = CannotStartProgram;
+			score = 0;
+			message = QString("Watcher reported an invalid result: %1").arg(code);
+			break;
 	}
 
 	delete runner;
@@ -1112,8 +1275,12 @@ void JudgingThread::judgeOutput() {
 			compareRealNumbers(fileName);
 			break;
 
-		case Task::SpecialJudgeMode:
-			specialJudge(fileName);
+		case Task::LemonSpecialJudgeMode:
+			lemonSpecialJudge(fileName);
+			break;
+
+		case Task::TestlibSpecialJudgeMode:
+			testlibSpecialJudge(fileName);
 			break;
 	}
 }
@@ -1187,8 +1354,12 @@ void JudgingThread::judgeAnswersOnlyTask() {
 			compareRealNumbers(answerFile);
 			break;
 
-		case Task::SpecialJudgeMode:
-			specialJudge(answerFile);
+		case Task::LemonSpecialJudgeMode:
+			lemonSpecialJudge(answerFile);
+			break;
+
+		case Task::TestlibSpecialJudgeMode:
+			testlibSpecialJudge(answerFile);
 			break;
 	}
 }
