@@ -149,6 +149,7 @@ auto TaskJudger::traditionalTaskPrepare() -> bool {
 		compilerTimeLimitRatio = i->getTimeLimitRatio();
 		compilerMemoryLimitRatio = i->getMemoryLimitRatio();
 		disableMemoryLimitCheck = i->getDisableMemoryLimitCheck();
+		interpreterAsWatcher = i->getInterpreterAsWatcher();
 		environment = i->getEnvironment();
 		QStringList values = QProcessEnvironment::systemEnvironment().toStringList();
 
@@ -478,12 +479,16 @@ int TaskJudger::judge() {
 			if (task->getTaskType() != Task::AnswersOnly) {
 				thread->setEnvironment(environment);
 				thread->setTimeLimit(qCeil(curTestCase->getTimeLimit() * compilerTimeLimitRatio));
+				thread->setRawTimeLimit(qCeil(curTestCase->getTimeLimit()));
 
 				if (disableMemoryLimitCheck) {
 					thread->setMemoryLimit(-1);
 				} else {
 					thread->setMemoryLimit(qCeil(curTestCase->getMemoryLimit() * compilerMemoryLimitRatio));
 				}
+				thread->setRawMemoryLimit(curTestCase->getMemoryLimit());
+
+				thread->setInterpreterAsWatcher(interpreterAsWatcher);
 			}
 			thread->start();
 			thread->wait();
@@ -519,10 +524,10 @@ int TaskJudger::judge() {
 					    qMin(nowScore, statusToScore(overallStatus[i], task->getTestCase(i)->getFullScore()));
 			}
 
-			emit singleCaseFinished(task->getTestCase(i)->getTimeLimit(), i, j, int(result[i][j]),
-			                        (j + 1 == task->getTestCase(i)->getInputFiles().size() ? 1 : -1) *
-			                            nowScore,
-			                        timeUsed[i][j], memoryUsed[i][j]);
+			emit singleCaseFinished(
+			    contestantName, task->getTestCase(i)->getTimeLimit(), i, j, int(result[i][j]),
+			    (j + 1 == task->getTestCase(i)->getInputFiles().size() ? 1 : -1) * nowScore, timeUsed[i][j],
+			    memoryUsed[i][j]);
 
 			if (score[i][j] < testCaseScore[i])
 				testCaseScore[i] = score[i][j];
@@ -534,8 +539,8 @@ int TaskJudger::judge() {
 
 void TaskJudger::makeDialogAlert(QString msg) { emit dialogAlert(std::move(msg)); }
 void TaskJudger::taskSkipped(const std::pair<int, int> &cur) {
-	emit singleCaseFinished(task->getTestCase(cur.first)->getTimeLimit(), cur.first, cur.second,
-	                        int(result[cur.first][cur.second]), 0, 0, 0);
+	emit singleCaseFinished(contestant->getContestantName(), task->getTestCase(cur.first)->getTimeLimit(),
+	                        cur.first, cur.second, int(result[cur.first][cur.second]), 0, 0, 0);
 }
 
 void TaskJudger::stop() { isJudging = false; }
