@@ -87,7 +87,7 @@ LemonLime::LemonLime(QWidget *parent) : QMainWindow(parent), ui(new Ui::LemonLim
 	connect(ui->closeAction, &QAction::triggered, this, &LemonLime::closeAction);
 	connect(ui->addTasksAction, &QAction::triggered, this, &LemonLime::addTasksAction);
 	connect(ui->exportAction, &QAction::triggered, this, &LemonLime::exportResult);
-	connect(ui->actionExportStatistics, &QAction::triggered, this, &LemonLime::exportStatstics);
+	connect(ui->actionExportStatistics, &QAction::triggered, this, &LemonLime::exportStatistics);
 	connect(ui->aboutAction, &QAction::triggered, this, &LemonLime::aboutLemon);
 	connect(ui->actionManual, &QAction::triggered, this, &LemonLime::actionManual);
 	connect(ui->actionMore, &QAction::triggered, this, &LemonLime::actionMore);
@@ -887,8 +887,8 @@ void LemonLime::addTaskWithScoreScale(const QString &title,
 	}
 }
 
-auto LemonLime::compareFileName(const std::pair<QString, QString> &a, const std::pair<QString, QString> &b)
-    -> bool {
+auto LemonLime::compareFileName(const std::pair<QString, QString> &a,
+                                const std::pair<QString, QString> &b) -> bool {
 	return (a.first.length() < b.first.length()) ||
 	       (a.first.length() == b.first.length() && QString::localeAwareCompare(a.first, b.first) < 0);
 }
@@ -922,8 +922,7 @@ void LemonLime::addTasksAction() {
 			filters = settings->getOutputFileExtensions();
 
 			if (filters.isEmpty())
-				filters << "out"
-				        << "ans";
+				filters << "out" << "ans";
 
 			for (int j = 0; j < filters.size(); j++) {
 				filters[j] = QString("*.") + filters[j];
@@ -976,7 +975,7 @@ void LemonLime::addTasksAction() {
 
 void LemonLime::exportResult() { ExportUtil::exportResult(this, curContest); }
 
-void LemonLime::exportStatstics() { StatisticsBrowser::exportStatstics(this, curContest); }
+void LemonLime::exportStatistics() { StatisticsBrowser::exportStatistics(this, curContest); }
 
 void LemonLime::changeContestName() {
 	if (! curContest) {
@@ -1002,10 +1001,10 @@ void LemonLime::changeContestName() {
 void LemonLime::aboutLemon() {
 	QString text;
 	text += "<h2>Project LemonLime</h2>";
-	text += "<h3>" +
-	        tr("Version: %1")
-	            .arg(QString(LEMON_VERSION_STRING) + QString(":") + QString::number(LEMON_VERSION_BUILD)) +
-	        "</h3>";
+	text +=
+	    "<h3>" +
+	    tr("Version: %1").arg(QString(LEMON_VERSION_STRING) + QString(":") + QString(LEMON_VERSION_BUILD)) +
+	    "</h3>";
 	text += tr("This is a tiny judging environment for OI contest based on Project LemonPlus.") + "<br>";
 	text += tr("Based on Project Lemon version 1.2 Beta by Zhipeng Jia, 2011") + "<br>";
 	text += tr("Based on Project LemonPlus by Dust1404, 2019") + "<br>";
